@@ -13,12 +13,23 @@ russian_coord_tweets
 ## ----results='hide'-----------------------------------------------------------
 length(russian_coord_tweets$content_id) == nrow(russian_coord_tweets)
 
-
 ## ----results='hide'-----------------------------------------------------------
 result <- detect_groups(russian_coord_tweets,
                         min_participation = 2,
                         time_window = 600)
 
+## -----------------------------------------------------------------------------
+combined_accounts <- c(result$account_id, result$account_id_y)
+combined_accounts_dt <- data.table::data.table(account_id = combined_accounts)
+account_counts <- combined_accounts_dt[, .N, by = account_id]
+
+russian_coord_tweets <- data.table::as.data.table(russian_coord_tweets)
+raw_counts <- russian_coord_tweets[, .N, by = account_id]
+raw_counts_included <- raw_counts[account_id %in% combined_accounts] 
+
+# min_participation
+min(raw_counts_included$N)
+
 ## -----------------------------------------------------------------------------
 coord_graph <- generate_coordinated_network(result, edge_weight = 0.99, objects = TRUE)
 
@@ -28,10 +39,10 @@ library(igraph)
 min(E(coord_graph)$weight[E(coord_graph)$weight_threshold == 1])
 
 ## ----results='hide'-----------------------------------------------------------
-summary_groups <- group_stats(coord_graph, weight_threshold = "full")
+summary_groups <- group_stats(coord_graph = coord_graph, weight_threshold = "full")
 
 ## ----results='hide'-----------------------------------------------------------
-summary_accounts <- account_stats(coord_graph, result, weight_threshold = "full")
+summary_accounts <- account_stats(coord_graph = coord_graph, result = result, weight_threshold = "full")
 
 ## -----------------------------------------------------------------------------
 result_update <- flag_speed_share(russian_coord_tweets, result, min_participation = 2, time_window = 120)
@@ -94,9 +105,9 @@ coord_graph_fast <-
 #  
 
 ## ----results='hide', eval=FALSE-----------------------------------------------
-#  summary_groups <- group_stats(result, network = "full")
+#  summary_groups <- group_stats(coord_graph = coord_graph, weight_threshold = "full")
 #  
 
 ## ----results='hide', eval=FALSE-----------------------------------------------
-#  summary_accounts <- account_stats(result, weight_threshold = "fast")
+#  summary_accounts <- account_stats(coord_graph = coord_graph, result = result, weight_threshold = "fast")
 
